@@ -1,7 +1,6 @@
 import warnings
 
-from flask import current_app, request
-from flask import session
+from flask import current_app, request, session
 from jinja2 import Markup
 from werkzeug.datastructures import CombinedMultiDict, ImmutableMultiDict
 from werkzeug.utils import cached_property
@@ -70,7 +69,7 @@ class FlaskForm(Form):
 
         def get_translations(self, form):
             if not current_app.config.get('WTF_I18N_ENABLED', True):
-                return None
+                return super(FlaskForm.Meta, self).get_translations(form)
 
             return translations
 
@@ -80,7 +79,7 @@ class FlaskForm(Form):
         if csrf_enabled is not None:
             warnings.warn(FlaskWTFDeprecationWarning(
                 '"csrf_enabled" is deprecated and will be removed in 1.0. '
-                'Set "meta.csrf" instead.'
+                "Pass meta={'csrf': False} instead."
             ), stacklevel=3)
             kwargs['meta'] = kwargs.get('meta') or {}
             kwargs['meta'].setdefault('csrf', csrf_enabled)
